Description: Lists all of the available service-specific resources, actions, and condition keys that can be used in IAM policies to control access to Amazon Elastic Block Store.

Actions, resources, and condition keys for Amazon Elastic Block Store - Service Authorization Reference

# Actions, resources, and condition keys for Amazon Elastic Block Store

Amazon Elastic Block Store (service prefix: `ebs` ) provides the following service-specific resources, actions, and condition context keys for use in IAM permission policies.

References:

- Learn how to configure this service .

- View a list of the API operations available for this service .

- Learn how to secure this service and its resources by using IAM permission policies.

Topics

- Actions defined by Amazon Elastic Block Store
- Resource types defined by Amazon Elastic Block Store
- Condition keys for Amazon Elastic Block Store

## Actions defined by Amazon Elastic Block Store

You can specify the following actions in the `Action` element of an IAM policy statement. Use policies to grant permissions to perform an operation in AWS. When you use an action in a policy, you usually allow or deny access to the API operation or CLI command with the same name. However, in some cases, a single action controls access to more than one operation. Alternatively, some operations require several different actions.

The Resource types column indicates whether each action supports resource-level permissions. If there is no value for this column, you must specify all resources ("*") in the `Resource` element of your policy statement. If the column includes a resource type, then you can specify an ARN of that type in a statement with that action. Required resources are indicated in the table with an asterisk (*). If you specify a resource-level permission ARN in a statement using this action, then it must be of this type. Some actions support multiple resource types. If the resource type is optional (not indicated as required), then you can choose to use one but not the other.

For details about the columns in the following table, see The actions table .

Actions | Description | Access level | Resource types (*required) | Condition keys | Dependent actions
--- | --- | --- | --- | --- | ---
CompleteSnapshot | Grants permission to seal and complete the snapshot after all of the required blocks of data have been written to it. | Write | snapshot* |  |
GetSnapshotBlock | Grants permission to return the data of a block in an Amazon Elastic Block Store (EBS) snapshot | Read | snapshot* |  |
ListChangedBlocks | Grants permission to list the blocks that are different between two Amazon Elastic Block Store (EBS) snapshots of the same volume/snapshot lineage | Read | snapshot* |  |
ListSnapshotBlocks | Grants permission to list the blocks in an Amazon Elastic Block Store (EBS) snapshot. | Read | snapshot* |  |
PutSnapshotBlock | Grants permission to write a block of data to a snapshot created by the StartSnapshot operation. | Write | snapshot* |  |
StartSnapshot | Grants permission to create a new EBS snapshot. | Write | snapshot |  |
| aws:RequestTag/${TagKey} aws:TagKeys |

## Resource types defined by Amazon Elastic Block Store

The following resource types are defined by this service and can be used in the `Resource` element of IAM permission policy statements. Each action in the Actions table identifies the resource types that can be specified with that action. A resource type can also define which condition keys you can include in a policy. These keys are displayed in the last column of the table. For details about the columns in the following table, see The resource types table .

Resource types | ARN | Condition keys
--- | --- | ---
snapshot | `arn:$ { Partition}:ec2:$ { Region}::snapshot/$ { SnapshotId}` | aws:RequestTag/${TagKey} aws:ResourceTag/${TagKey} aws:TagKeys ebs:Description ebs:ParentSnapshot ebs:VolumeSize

## Condition keys for Amazon Elastic Block Store

Amazon Elastic Block Store defines the following condition keys that can be used in the `Condition` element of an IAM policy. You can use these keys to further refine the conditions under which the policy statement applies. For details about the columns in the following table, see The condition keys table .

To view the global condition keys that are available to all services, see Available global condition keys .

Condition keys | Description | Type
--- | --- | ---
aws:RequestTag/${TagKey} | Filters access by a tag key and value pair that is allowed in the request | String
aws:ResourceTag/${TagKey} | Filters access based on tag key-value pairs assigned to the AWS resource | String
aws:TagKeys | Filters access by a list of tag keys that are allowed in the request | String
ebs:Description | Filters access by the description of the snapshot being created. | String
ebs:ParentSnapshot | Filters access by the ID of the parent snapshot. | String
ebs:VolumeSize | Filters access by the size of the volume for the snapshot being created, in GiB. | Numeric

Did this page help you? - Yes

Thanks for letting us know we're doing a good job!

If you've got a moment, please tell us what we did right so we can do more of it.

Did this page help you? - No

Thanks for letting us know this page needs work. We're sorry we let you down.

If you've got a moment, please tell us how we can make the documentation better.